Snakemake Report

Loading Snakemake Report...

Please enable Javascript in your browser to see this report.

Loading 150.6 kB. For large reports, this can take a while.

## Workflow

This is the workflow description. Test reference fig1.svg.

Click the nodes to obtain details about each step.

## Other

## Step 1

## Step 2

#### testmodel

## Statistics

If the workflow has been executed in cluster/cloud, runtimes include the waiting time in the queue.

Loading...

#####

##### Rule a

Rule properties
Jobs | 1
Input files
test.0.out test.1.out test.2.out test.3.out test.4.out test.5.out test.6.out test.7.out test.8.out test.9.out
Output files
fig1.svg
Code
    1
    sleep `shuf -i 1-3 -n 1`; cp data/fig1.svg {output}

##### Rule c

Rule properties
Jobs | 10
Output files
test.{i}.out
Container image
docker://continuumio/miniconda3:4.4.10
Code
    1
    sleep `shuf -i 1-3 -n 1`; touch {output}

##### Rule d

Rule properties
Jobs | 1
Output files
test.csv

##### Rule e

Rule properties
Jobs | 1
Output files
testdir
Code
    1
    2
    3
    4
    5
    6
            mkdir {output}
            for x in 1 2 3
            do
                echo $x > testdir/$x.txt
            done